@@ -1,12 +1,10 @@
-# -*- Mode:Python; indent-tabs-mode:nil; tab-width:4 -*-
+# -*- Mode:Python; indent-tabs-mode:nil; tab-width:4; encoding:utf8 -*-
 #
 # Copyright 2002 Ben Escoto <ben@emerose.org>
 # Copyright 2007 Kenneth Loafman <kenneth@loafman.com>
 # Copyright 2011 Alexander Zangerl <az@snafu.priv.at>
 # Copyright 2012 edso (ssh_config added)
 #
-# $Id: sshbackend.py,v 1.2 2011/12/31 04:44:12 az Exp $
-#
 # This file is part of duplicity.
 #
 # Duplicity is free software; you can redistribute it and/or modify it
@@ -33,15 +31,15 @@ import getpass
 import logging
 import os
 import re
-import string
 import sys
 import warnings
 
 from binascii import hexlify
 
 import duplicity.backend
-from duplicity import globals
-from duplicity import log
+from duplicity import progress
+from duplicity import config
+from duplicity import util
 from duplicity.errors import BackendException
 
 global paramiko
@@ -205,10 +203,10 @@ Are you sure you want to continue connecting (yes/no)? """ % (hostname,
             self.config.update({u'port': 22})
         # parse ssh options for alternative ssh private key, identity file
         m = re.search(r"^(?:.+\s+)?(?:-oIdentityFile=|-i\s+)(([\"'])([^\\2]+)\\2|[\S]+).*",
-                      globals.ssh_options)
+                      config.ssh_options)
         if (m is not None):
             keyfilename = m.group(3) if m.group(3) else m.group(1)
-            self.config[u'identityfile'] = keyfilename
+            self.config[u'identityfile'] = keyfilename.strip(u'\'\"')
         # ensure ~ is expanded and identity exists in dictionary
         if u'identityfile' in self.config:
             if not isinstance(self.config[u'identityfile'], list):
@@ -228,7 +226,7 @@ Are you sure you want to continue connecting (yes/no)? """ % (hostname,
             self.config[u'identityfile'] = None
 
         # get password, enable prompt if askpass is set
-        self.use_getpass = globals.ssh_askpass
+        self.use_getpass = config.ssh_askpass
         # set url values for beautiful login prompt
         parsed_url.username = self.config[u'user']
         parsed_url.hostname = self.config[u'hostname']
@@ -247,7 +245,7 @@ Are you sure you want to continue connecting (yes/no)? """ % (hostname,
                 self.config[u'user'],
                 self.config[u'hostname'],
                 self.config[u'port'], e))
-        self.client.get_transport().set_keepalive((int)(globals.timeout / 2))
+        self.client.get_transport().set_keepalive((int)(config.timeout / 2))
 
         self.scheme = duplicity.backend.strip_prefix(parsed_url.scheme,
                                                      u'paramiko')
@@ -296,12 +294,12 @@ Are you sure you want to continue connecting (yes/no)? """ % (hostname,
 
     def _put(self, source_path, remote_filename):
         # remote_filename is a byte object, not str or unicode
-        remote_filename = remote_filename.decode(u"utf-8")
+        remote_filename = util.fsdecode(remote_filename)
         if self.use_scp:
             f = open(source_path.name, u'rb')
             try:
                 chan = self.client.get_transport().open_session()
-                chan.settimeout(globals.timeout)
+                chan.settimeout(config.timeout)
                 # scp in sink mode uses the arg as base directory
                 chan.exec_command(u"scp -t '%s'" % self.remote_dir)
             except Exception as e:
@@ -318,22 +316,28 @@ Are you sure you want to continue connecting (yes/no)? """ % (hostname,
             response = chan.recv(1)
             if (response != b"\0"):
                 raise BackendException(b"scp remote error: %b" % chan.recv(-1))
-            chan.sendall(f.read() + b'\0')
+            file_pos = 0
+            file_size = fstat.st_size
+            while file_pos < file_size:
+                chan.sendall(f.read(16384))
+                file_pos = f.tell()
+                progress.report_transfer(file_pos, file_size)
+            chan.sendall(b'\0')
             f.close()
             response = chan.recv(1)
             if (response != b"\0"):
                 raise BackendException(u"scp remote error: %s" % chan.recv(-1))
             chan.close()
         else:
-            self.sftp.put(source_path.name, remote_filename)
+            self.sftp.put(source_path.name, remote_filename, callback=progress.report_transfer)
 
     def _get(self, remote_filename, local_path):
         # remote_filename is a byte object, not str or unicode
-        remote_filename = remote_filename.decode(u"utf-8")
+        remote_filename = util.fsdecode(remote_filename)
         if self.use_scp:
             try:
                 chan = self.client.get_transport().open_session()
-                chan.settimeout(globals.timeout)
+                chan.settimeout(config.timeout)
                 chan.exec_command(u"scp -f '%s/%s'" % (self.remote_dir,
                                                        remote_filename))
             except Exception as e:
@@ -386,6 +390,8 @@ Are you sure you want to continue connecting (yes/no)? """ % (hostname,
             return self.sftp.listdir()
 
     def _delete(self, filename):
+        # filename is a byte object, not str or unicode
+        filename = util.fsdecode(filename)
         # In scp mode unavoidable quoting issues will cause failures if
         # filenames containing single quotes are encountered.
         if self.use_scp:
@@ -399,13 +405,13 @@ Are you sure you want to continue connecting (yes/no)? """ % (hostname,
         command and returns stdout of command. throws an exception if exit
         code!=0 and not ignored"""
         try:
-            ch_in, ch_out, ch_err = self.client.exec_command(cmd, -1, globals.timeout)
+            ch_in, ch_out, ch_err = self.client.exec_command(cmd, -1, config.timeout)
             output = ch_out.read(-1)
             return output
         except Exception as e:
             if not ignoreexitcode:
                 raise BackendException(u"%sfailed: %s \n %s" % (
-                    errorprefix, ch_err.read(-1), e))
+                    errorprefix, cmd, util.uexc(e)))
 
     def gethostconfig(self, file, host):
         file = os.path.expanduser(file)
