@@ -99,6 +99,11 @@ def stdin_deprecation(opt):
             log.ERROR, force_print=True)
 
 
+# log options handled in log.py.  Add noop to make optparse happy
+def noop():
+    pass
+
+
 def expand_fn(filename):
     return os.path.expanduser(os.path.expandvars(filename))
 
@@ -241,7 +246,7 @@ def parse_cmdline_options(arglist):
 
     def add_rename(o, s, v, p):  # pylint: disable=unused-argument
         key = util.fsencode(os.path.normcase(os.path.normpath(v[0])))
-        globals.rename[key] = util.fsencode(v[1])
+        config.rename[key] = util.fsencode(v[1])
 
     parser = optparse.OptionParser(option_class=DupOption, usage=usage())
 
@@ -384,6 +389,9 @@ def parse_cmdline_options(arglist):
                       dest=u"", action=u"callback",
                       callback=lambda o, s, v, p: config.gpg_profile.hidden_recipients.append(v))
 
+    # Fake-root for iDrived backend
+    parser.add_option(u"--idr-fakeroot", dest=u"fakeroot", type=u"file", metavar=_(u"path"))
+
     # ignore (some) errors during operations; supposed to make it more
     # likely that you are able to restore data under problematic
     # circumstances. the default should absolutely always be False unless
@@ -431,6 +439,10 @@ def parse_cmdline_options(arglist):
                       dest=u"", action=u"callback",
                       callback=lambda o, s, v, p: log.add_file(v))
 
+    # log option to add timestamp and level to log entries
+    parser.add_option(u"--log-timestamp", action=u"callback",
+                      callback=lambda o, s, v, p: noop())
+
     # Maximum block size for large files
     parser.add_option(u"--max-blocksize", type=u"int", metavar=_(u"number"))
 
@@ -641,6 +653,9 @@ def parse_cmdline_options(arglist):
 
     parser.add_option(u"-V", u"--version", action=u"callback", callback=print_ver)
 
+    # option for mediafire to purge files on delete instead of sending to trash
+    parser.add_option(u"--mf-purge", action=u"store_true")
+
     # volume size
     # TRANSL: Used in usage help to represent a desired number of
     # something. Example:
@@ -993,12 +1008,14 @@ def usage():
   full <%(source_dir)s> <%(target_url)s>
   incr <%(source_dir)s> <%(target_url)s>
   list-current-files <%(target_url)s>
-  restore <%(source_url)s> <%(target_dir)s>
-  remove-older-than <%(time)s> <%(target_url)s>
   remove-all-but-n-full <%(count)s> <%(target_url)s>
   remove-all-inc-of-but-n-full <%(count)s> <%(target_url)s>
+  remove-older-than <%(time)s> <%(target_url)s>
+  replicate <%(source_url)s> <%(target_url)s>
+  restore <%(source_url)s> <%(target_dir)s>
   verify <%(target_url)s> <%(source_dir)s>
-  replicate <%(source_url)s> <%(target_url)s>""" % trans
+
+""" % trans
 
     return msg
 
